% Copy all files in Matlab current directory and type "writerrec" on
% Matlab command window.
%
%
%WRITER RECOGNITION SYSTEM
%
% Research in automatic writer identification has mainly focused on the statistical approach. This
% has led to the specification and extraction of statistical features such as run-length distributions,
% slant distribution, entropy, and edge-hinge distribution. The edge-hinge distribution feature 
% outperforms all other statistical features. 
% Edge-hinge distribution is a feature that characterizes the changes in direction of a writing
% stroke in handwritten text. The edge-hinge distribution is extracted by means of a window that
% is slid over an edge-detected binary handwriting image. Whenever the central pixel of the window
% is on, the two edge fragments (i.e. connected sequences of pixels) emerging from this central pixel
% are considered. Their directions are measured and stored as pairs. A joint probability distribution
% is obtained from a large sample of such pairs. 
%
% We have improved Laurens van der Maaten's excellent package for writer identification available at 
% http://www.cs.unimaas.nl/l.vandermaaten/Laurens%20van%20der%20Maaten/Home.html
% We consider a complete 2D probability distribution that takes into
% account all possible combinations of angles pairs, outperforming original
% code.
%
% The images included are taken from IAM Handwriting Database, available at
% http://www.iam.unibe.ch/~fki/iamDB/
% See the cited references for more informations.
%
% 
% First, select an input image clicking on "Select image".
% If you want you can crop input image by selecting top-left and bottom-right corners, or, 
% equivalently, top-right and bottom-left. This is necessary to avoid
% regions where there is no handwritten text (such as printed text,
% separation lines,...).
%
% Then you can
%   - add this image to database (click on "Add selected image to database"
%   - perform face recognition (click on "Writer Recognition" button)
%     Note: If you want to perform writer recognition database has to include 
%     at least one image.
%  If you choose to add image to database, a positive integer (writer ID) is
%  required. This posivive integer is a progressive number which identifies
%  a writer (each writer corresponds to an ID).
%
% For example:
%  - run the GUI (type "writerrec" on Matlab command window)
%  - delete database (click on "Delete Database")
%  - add "Mike_1.jpg" to database ---> the ID has to be 1 since Mike is the first writer you are adding to database
%  - add "Mike_2.jpg" to database ---> the ID has to be 1 since you have already added a Mike's handwritten text to database
%  - add "Paul_1.jpg" to database ---> the ID has to be 2 since Paul is the second writer you are adding to database
%  - add "Cindy_1.jpg" to database ---> the ID has to be 3 since Cindy is the third writer you are adding to database
%  - add "Paul_2.jpg" to database ---> the ID has to be 2 once again since you have already added Paul's handwritten text to database
%   
% ... and so on! Very simple, isnt't? :)
% 
% The recognition gives as results the ID of "nearest" writer present in
% database. For example if you select image "Paul_3.jpg" the ID given SHOULD
% be 2: "it should be" because errors are possible.
%
%
% 
% 
% FUNCTIONS
%
% Select image:                                  read the input image
%
% Add selected image to database:                the input image is added to database and will be used for training
%
% Database Info:                                 show informations about the images present in database. 
%
% Writer Recognition:                            writer matching. The selected input image is processed
%
% Delete Database:                               remove database from the current directory
%
% Info:                                          show informations about this software
%
%
% Source code for Writer Recognition System:     how to obtain the complete source code
%
% Exit:                                          quit program
%
%
%  References:
%   L.J.P. van der Maaten and E.O. Postma. Improving Automatic Writer
%   Identification. In Proceedings of the 17th BNAIC, pages 260-266. Brussels, Belgium, 2005.
%   This article is available at 
%   http://www.cs.unimaas.nl/l.vandermaaten/Laurens%20van%20der%20Maaten/Software_files/PaperBNAIC2005.pdf
%
%
%   IAM Handwriting Database, available at
%   http://www.iam.unibe.ch/~fki/iamDB/
%
%
%
%
%
%
% Luigi Rosa
% Via Centrale 35
% 67042 Civita di Bagno
% L'Aquila - ITALY 
% email  luigi.rosa@tiscali.it
% mobile +39 3207214179
% web site http://www.advancedsourcecode.com
%
%
%